@@ -1,10 +1,22 @@
+from typing import NamedTuple, Union, List, Sequence, Any
 import os
 import numpy as np
-# from supervised_learning import SupervisedLearnerPrimitiveBase
-# from tian_STMB_new import STMB
+
+from d3m_types.sequence import ndarray
+from primitive_interfaces.supervised_learning import SupervisedLearnerPrimitiveBase
+
 from rpi_featureSelection_python_tools.stmb_tools import *
 
-class STMBFeatureSelector():
+
+# These are just regular Python variables so that we can easily change all types
+# at once in the future, if needed. Otherwise, one could simply inline all these.
+Inputs = ndarray
+Outputs = ndarray
+
+
+class STMBFeatureSelector(SupervisedLearnerPrimitiveBase[Inputs, Outputs]):
+
+	__author__ = "RPI DARPA D3M"
     """
     This class implements a feature selection method:
 
@@ -28,7 +40,7 @@ class STMBFeatureSelector():
     """
 
     def __init__(self):
-        # super(SupervisedLearnerPrimitiveBase, self).__init__()
+        super().__init__()
 
         self.is_feature_selection = True
         self.hyperparameters = {}
@@ -36,7 +48,7 @@ class STMBFeatureSelector():
         self.training_outputs = None
         self.fitted = False
 
-    def set_training_data(self, inputs, outputs):
+    def set_training_data(self, inputs: Inputs, outputs: Outputs) -> None:
         inputs = inputs.astype(np.float64)
         outputs = outputs.astype(np.float64)
         for i in np.arange(inputs.shape[1]):
@@ -49,7 +61,7 @@ class STMBFeatureSelector():
         self.training_outputs = outputs
         self.fitted = False
 
-    def fit(self):
+    def fit(self) -> None:
         if self.fitted:
             return True
 
@@ -68,7 +80,7 @@ class STMBFeatureSelector():
 
         return True
 
-    def produce(self, inputs):  # inputs: m x n numpy array
+    def produce(self, inputs: Inputs) -> Outputs:  # inputs: m x n numpy array
         if 'index' in self.hyperparameters.keys():
             return inputs[:, self.hyperparameters['index']]
         else:
