@@ -57,7 +57,7 @@ class STMBPlusFeatureSelector():
             raise ValueError('Missing training data, or missing values exist.')
 
         index = Auto_JMIplusSTMB(self.training_inputs, self.training_outputs)
-        index = np.array(index[0], dtype=np.int64)
+        index = np.array(index, dtype=np.int64)
         print (index.shape[0])
 
         if index.shape == ():
